Edycja danych rekordów - wydawnictwa zwarte, ciągłe, patenty, itp
=================================================================

Dodawanie autorów do rekordów
-----------------------------

Aby dodać autora do rekordu, podczas dodawania lub edycji nowego rekordu kliknij
"Dodaj kolejne powiązanie autora z wyd. ciągłym / wyd. zwartym / patentem ...".

Zmiana kolejności autorów
-----------------------------

Aby zmienić kolejność autorów, skorzystaj z przycisku przeciągania oraz techniki
"przeciągnij i upuść". Po prostu kliknij i przytrzymaj lewym przyciskiem myszy na
przycisku przeciągania i przeciągnij dane powiązanie autora z rekordem w górę
lub w dół. Przycisk przeciągania wygląda w następujący sposób:

.. image:: images/editor/przycisk_przeciagania.png
   :alt: Przycisk przeciągania

Możesz "zwinąć" formularz powiązania autora z rekordem aby zmiana kolejności autorów
była łatwiejsza, co ma szczególne znaczenie na monitorach o niewielkiej rozdzielczości.

Działania te również prezentuje film `Zmiana kolejności autorów`_ .

.. raw:: html

    <iframe width="560" height="315" src="https://www.youtube.com/embed/oruEX3CykH8" frameborder="0" allow="autoplay; encrypted-media" allowfullscreen></iframe>


.. _Zmiana kolejności autorów: https://www.youtube.com/embed/oruEX3CykH8
